==> wh_lookml_gen-0.2.1.tar.gz: wh_lookml_gen-0.2.1/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0',
                'altgraph==0.17',
                'arrow==1.1.0',
                'attrs==20.3.0',
                'binaryornot==0.4.4',
                'bleach==3.3.0',
                'boto3==1.17.78',
                'botocore==1.18.18',
                'cachetools==4.2.1',
                'certifi==2020.12.5',
                'cffi==1.14.5',
                'chardet==3.0.4',
                'click==8.0.1',
                'colorama==0.4.4',
                'cookiecutter==1.7.3',
                'docopt==0.6.2',
                'docutils==0.17.1',
                'gitdb==4.0.7',
                'GitPython==3.1.17',
                'google-api-core==1.28.0',
                'google-auth==1.28.1',
                'google-auth-oauthlib==0.4.4',
                'google-cloud-bigquery==2.17.0',
                'google-cloud-bigquery-storage==2.4.0',
                'google-cloud-core==1.6.0',
                'google-crc32c==1.1.2',
                'google-resumable-media==1.3.0',
                'googleapis-common-protos==1.53.0',
                'grpcio==1.38.0',
                'idna==2.9',
                'importlib-metadata==3.9.0',
                'isodate==0.6.0',
                'Jinja2==3.0.1',
                'jinja2-time==0.2.0',
                'jmespath==0.10.0',
                'keyring==23.0.1',
                'libcst==0.3.19',
                'lkml==1.1.0',
                'macholib==1.14',
                'MarkupSafe==2.0.1',
                'mypy-extensions==0.4.3',
                'numpy==1.20.2',
                'oauthlib==3.1.0',
                'packaging==20.9',
                'pandas==0.24.2',
                'pandas-gbq==0.15.0',
                'pandas-redshift==2.0.5',
                'pkginfo==1.7.0',
                'poyo==0.5.0',
                'proto-plus==1.18.1',
                'protobuf==3.15.6',
                'psycopg2-binary==2.8.6',
                'pyarrow==4.0.0',
                'pyasn1==0.4.8',
                'pyasn1-modules==0.2.8',
                'pycparser==2.20',
                'pydata-google-auth==1.2.0',
                'Pygments==2.9.0',
                'pyinstaller==4.3',
                'pyinstaller-hooks-contrib==2021.1',
                'pyparsing==2.4.7',
                'pyrsistent==0.17.3',
                'python-dateutil==2.8.1',
                'python-slugify==4.0.1',
                'pytimeparse==1.1.8',
                'pytz==2020.5',
                'PyYAML==5.4.1',
                'readme-renderer==29.0',
                'requests==2.23.0',
                'requests-oauthlib==1.3.0',
                'requests-toolbelt==0.9.1',
                'rfc3986==1.5.0',
                'rsa==4.7.2',
                's3transfer==0.3.6',
                'six==1.15.0',
                'smmap==4.0.0',
                'text-unidecode==1.3',
                'tqdm==4.60.0',
                'twine==3.4.1',
                'typing-extensions==3.7.4.3',
                'typing-inspect==0.6.0',
                'urllib3==1.25.11',
                'webencodings==0.5.1',
                'zipp==3.4.1'

                    ]

test_requirements = [ ]

setup(
    author="Lewis Baker",
    author_email='lewischarlebaker@gmail.com',
    python_requires='>=3.6',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="generates lookml from a warehouse",
    entry_points={
        'console_scripts': [
            'wh_lookml_gen=wh_lookml_gen.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='wh_lookml_gen',
    name='wh_lookml_gen',
    packages=find_packages(include=['wh_lookml_gen', 'wh_lookml_gen.*']),
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/lewischarlesbaker/wh_lookml_gen',
    version='0.2.1',
    zip_safe=False,
)

==> wh_lookml_gen-0.2.2.tar.gz: wh_lookml_gen-0.2.2/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0', ]

test_requirements = [ ]

setup(
    author="Lewis Baker",
    author_email='lewischarlebaker@gmail.com',
    python_requires='>=3.6',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="generates lookml from a warehouse",
    entry_points={
        'console_scripts': [
        'wh_lookml_gen=wh_lookml_gen.cli:lookml',
        'wh_schema_gen=wh_lookml_gen.schema_cli:schema',
        'wh_init_gen=wh_lookml_gen.wh_init_cli:init'
        
        ]
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='wh_lookml_gen',
    name='wh_lookml_gen',
    packages=find_packages(include=['wh_lookml_gen', 'wh_lookml_gen.*']),
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/lewischarlesbaker/wh_lookml_gen',
    version='0.2.2',
    zip_safe=False,
)
